if __name__ == '__main__':
    import sys
    import conda_workon

    sys.exit(conda_workon.main_workon())
